==> zio-aws-docdb_2.13-5.17.146.2-sources.jar: zio/aws/docdb/model/DeleteDbClusterResponse.scala <==
package zio.aws.docdb.model
import zio.ZIO
import zio.aws.core.{AwsError, BuilderHelper}
import scala.jdk.CollectionConverters._
final case class DeleteDbClusterResponse(
    dbCluster: Option[zio.aws.docdb.model.DBCluster] = None
) {
  def buildAwsValue()
      : software.amazon.awssdk.services.docdb.model.DeleteDbClusterResponse = {
    import DeleteDbClusterResponse.zioAwsBuilderHelper.BuilderOps
    software.amazon.awssdk.services.docdb.model.DeleteDbClusterResponse
      .builder()
      .optionallyWith(dbCluster.map(value => value.buildAwsValue()))(
        _.dbCluster
      )
      .build()
  }
  def asReadOnly: zio.aws.docdb.model.DeleteDbClusterResponse.ReadOnly =
    zio.aws.docdb.model.DeleteDbClusterResponse.wrap(buildAwsValue())
}
object DeleteDbClusterResponse {
  private lazy val zioAwsBuilderHelper: BuilderHelper[
    software.amazon.awssdk.services.docdb.model.DeleteDbClusterResponse
  ] = BuilderHelper.apply
  trait ReadOnly {
    def asEditable: zio.aws.docdb.model.DeleteDbClusterResponse =
      zio.aws.docdb.model
        .DeleteDbClusterResponse(dbCluster.map(value => value.asEditable))
    def dbCluster: Option[zio.aws.docdb.model.DBCluster.ReadOnly]
    def getDbCluster
        : ZIO[Any, AwsError, zio.aws.docdb.model.DBCluster.ReadOnly] =
      AwsError.unwrapOptionField("dbCluster", dbCluster)
  }
  private final class Wrapper(
      impl: software.amazon.awssdk.services.docdb.model.DeleteDbClusterResponse
  ) extends zio.aws.docdb.model.DeleteDbClusterResponse.ReadOnly {
    override val dbCluster: Option[zio.aws.docdb.model.DBCluster.ReadOnly] =
      scala
        .Option(impl.dbCluster())
        .map(value => zio.aws.docdb.model.DBCluster.wrap(value))
  }
  def wrap(
      impl: software.amazon.awssdk.services.docdb.model.DeleteDbClusterResponse
  ): zio.aws.docdb.model.DeleteDbClusterResponse.ReadOnly = new Wrapper(impl)
}

==> zio-aws-docdb_2.13-5.20.7.3-sources.jar: zio/aws/docdb/model/DeleteDbClusterResponse.scala <==
package zio.aws.docdb.model
import zio.ZIO
import zio.aws.core.{AwsError, BuilderHelper}
import zio.prelude.data.Optional
import scala.jdk.CollectionConverters._
final case class DeleteDbClusterResponse(
    dbCluster: Optional[zio.aws.docdb.model.DBCluster] = Optional.Absent
) {
  def buildAwsValue()
      : software.amazon.awssdk.services.docdb.model.DeleteDbClusterResponse = {
    import DeleteDbClusterResponse.zioAwsBuilderHelper.BuilderOps
    software.amazon.awssdk.services.docdb.model.DeleteDbClusterResponse
      .builder()
      .optionallyWith(dbCluster.map(value => value.buildAwsValue()))(
        _.dbCluster
      )
      .build()
  }
  def asReadOnly: zio.aws.docdb.model.DeleteDbClusterResponse.ReadOnly =
    zio.aws.docdb.model.DeleteDbClusterResponse.wrap(buildAwsValue())
}
object DeleteDbClusterResponse {
  private lazy val zioAwsBuilderHelper: BuilderHelper[
    software.amazon.awssdk.services.docdb.model.DeleteDbClusterResponse
  ] = BuilderHelper.apply
  trait ReadOnly {
    def asEditable: zio.aws.docdb.model.DeleteDbClusterResponse =
      zio.aws.docdb.model
        .DeleteDbClusterResponse(dbCluster.map(value => value.asEditable))
    def dbCluster: Optional[zio.aws.docdb.model.DBCluster.ReadOnly]
    def getDbCluster
        : ZIO[Any, AwsError, zio.aws.docdb.model.DBCluster.ReadOnly] =
      AwsError.unwrapOptionField("dbCluster", dbCluster)
  }
  private final class Wrapper(
      impl: software.amazon.awssdk.services.docdb.model.DeleteDbClusterResponse
  ) extends zio.aws.docdb.model.DeleteDbClusterResponse.ReadOnly {
    override val dbCluster: Optional[zio.aws.docdb.model.DBCluster.ReadOnly] =
      zio.aws.core.internal
        .optionalFromNullable(impl.dbCluster())
        .map(value => zio.aws.docdb.model.DBCluster.wrap(value))
  }
  def wrap(
      impl: software.amazon.awssdk.services.docdb.model.DeleteDbClusterResponse
  ): zio.aws.docdb.model.DeleteDbClusterResponse.ReadOnly = new Wrapper(impl)
}
